@@ -173,7 +173,7 @@ varcov <- function(
   }
   
   # fixMu(mu,nGroup,nNode,"mu" %in% equal)
-  
+
   # Fix sigma
   if (type == "cov"){
     if (corinput){
@@ -265,22 +265,22 @@ varcov <- function(
     model@extramatrices <- list(
       D = psychonetrics::duplicationMatrix(nNode), # non-strict duplciation matrix
       L = psychonetrics::eliminationMatrix(nNode), # Elinimation matrix
-      In = as(diag(nNode),"dgCMatrix") # Identity of dim n
+      In = as(diag(nNode),"dMatrix") # Identity of dim n
     )
   } else if (type == "chol"){
     model@extramatrices <- list(
       D = psychonetrics::duplicationMatrix(nNode), # non-strict duplciation matrix
       L = psychonetrics::eliminationMatrix(nNode), # Elinimation matrix
-      In = as(diag(nNode),"dgCMatrix"), # Identity of dim n
+      In = as(diag(nNode),"dMatrix"), # Identity of dim n
       # C = as(lavaan::lav_matrix_commutation(nNode,nNode),"sparseMatrix")
-      C = as(lavaan::lav_matrix_commutation(nNode,nNode),"dgCMatrix")
+      C = as(lavaan::lav_matrix_commutation(nNode,nNode),"dMatrix")
     )
   } else if (type == "ggm" || type == "cor"){
     model@extramatrices <- list(
       D = psychonetrics::duplicationMatrix(nNode), # non-strict duplciation matrix
       L = psychonetrics::eliminationMatrix(nNode), # Elinimation matrix
       Dstar = psychonetrics::duplicationMatrix(nNode,diag = FALSE), # Strict duplicaton matrix
-      In = as(diag(nNode),"dgCMatrix"), # Identity of dim n
+      In = as(diag(nNode),"dMatrix"), # Identity of dim n
       A = psychonetrics::diagonalizationMatrix(nNode)
     )
   }
